@@ -1,10 +1,14 @@
 #!/usr/bin/env python2
 
-from gi.repository import Gio, Gtk, GObject, Gdk, GLib, GdkPixbuf
+import gi
+gi.require_version('CDesktopEnums', '3.0')
+gi.require_version('CinnamonDesktop', '3.0')
+from gi.repository import Gio, Gtk, GObject, Gdk, GLib, GdkPixbuf, CDesktopEnums, CinnamonDesktop
 import math
 import os
 import subprocess
 import traceback
+import dbus
 
 settings_objects = {}
 
@@ -549,10 +553,11 @@ class SettingsPage(Gtk.Box):
 
         return section
 
-    def add_reveal_section(self, title, schema=None, key=None):
+    def add_reveal_section(self, title, schema=None, key=None, values=None):
         section = SettingsBox(title)
-        revealer = SettingsRevealer(schema, key)
+        revealer = SettingsRevealer(schema, key, values)
         revealer.add(section)
+        section._revealer = revealer
         self.pack_start(revealer, False, False, 0)
 
         return section
@@ -945,9 +950,10 @@ class GSettingsComboBox(SettingsWidget):
         self.pack_end(self.content_widget, False, False, 0)
         self.content_widget.show_all()
 
+        self.on_my_setting_changed()
+
         self.content_widget.connect('changed', self.on_my_value_changed)
         self.settings.connect("changed::" + self.key, self.on_my_setting_changed)
-        self.on_my_setting_changed()
 
         if size_group:
             self.add_to_size_group(size_group)
@@ -986,3 +992,243 @@ class GSettingsColorChooser(SettingsWidget):
 
         if size_group:
             self.add_to_size_group(size_group)
+
+class GSettingsSoundFileChooser(SettingsWidget):
+    def __init__(self, label, schema, key, dep_key=None, size_group=None):
+        super(GSettingsSoundFileChooser, self).__init__(dep_key=dep_key)
+
+        self.label = Gtk.Label(label)
+
+        self.content_widget = Gtk.ButtonBox(Gtk.Orientation.HORIZONTAL)
+
+        c = self.content_widget.get_style_context()
+        c.add_class(Gtk.STYLE_CLASS_LINKED)
+
+        self.key = key
+        self.settings = self.get_settings(schema)
+
+        self.pack_start(self.label, False, False, 0)
+        self.pack_end(self.content_widget, False, False, 0)
+
+        self.file_picker = Gtk.Button()
+        self.file_picker.connect("clicked", self.on_picker_clicked)
+        self.update_button_label(self.settings.get_string(self.key))
+
+        self.content_widget.add(self.file_picker)
+
+        self.play_button = Gtk.Button()
+        self.play_button.set_image(Gtk.Image.new_from_stock("gtk-media-play", Gtk.IconSize.BUTTON))
+        self.play_button.connect("clicked", self.on_play_clicked)
+        self.content_widget.add(self.play_button)
+
+        self._proxy = None
+
+        try:
+            Gio.DBusProxy.new_for_bus(Gio.BusType.SESSION, Gio.DBusProxyFlags.NONE, None,
+                                      'org.cinnamon.SettingsDaemon',
+                                      '/org/cinnamon/SettingsDaemon/Sound',
+                                      'org.cinnamon.SettingsDaemon.Sound',
+                                      None, self._on_proxy_ready, None)
+        except dbus.exceptions.DBusException as e:
+            print(e)
+            self._proxy = None
+            self.play_button.set_sensitive(False)
+
+        if size_group:
+            self.add_to_size_group(size_group)
+
+    def _on_proxy_ready (self, object, result, data=None):
+        self._proxy = Gio.DBusProxy.new_for_bus_finish(result)
+
+    def on_play_clicked(self, widget):
+        self._proxy.PlaySoundFile("(us)", 0, self.settings.get_string(self.key))
+
+    def on_picker_clicked(self, widget):
+        dialog = Gtk.FileChooserDialog(title=self.label.get_text(),
+                                       action=Gtk.FileChooserAction.OPEN,
+                                       buttons=(_("_Cancel"), Gtk.ResponseType.CANCEL,
+                                                _("_Open"), Gtk.ResponseType.ACCEPT))
+
+        dialog.set_filename(self.settings.get_string(self.key))
+
+        sound_filter = Gtk.FileFilter()
+        sound_filter.add_mime_type("audio")
+        dialog.add_filter(sound_filter)
+
+        if (dialog.run() == Gtk.ResponseType.ACCEPT):
+            name = dialog.get_filename()
+            self.settings.set_string(self.key, name)
+            self.update_button_label(name)
+
+        dialog.destroy()
+
+    def update_button_label(self, absolute_path):
+        f = Gio.File.new_for_path(absolute_path)
+
+        self.file_picker.set_label(f.get_basename())
+
+
+class BinFileMonitor(GObject.GObject):
+    __gsignals__ = {
+        'changed': (GObject.SignalFlags.RUN_LAST, None, ()),
+    }
+    def __init__(self):
+        super(BinFileMonitor, self).__init__()
+
+        self.changed_id = 0
+
+        env = GLib.getenv("PATH")
+
+        if env == None:
+            env = "/bin:/usr/bin:."
+
+        self.paths = env.split(":")
+
+        self.monitors = []
+
+        for path in self.paths:
+            file = Gio.File.new_for_path(path)
+            mon = file.monitor_directory(Gio.FileMonitorFlags.WATCH_MOVES, None)
+            mon.connect("changed", self.queue_emit_changed)
+            self.monitors.append(mon)
+
+    def _emit_changed(self):
+        self.emit("changed")
+        self.changed_id = 0
+        return False
+
+    def queue_emit_changed(self, file, other, event_type, data=None):
+        if self.changed_id > 0:
+            GObject.source_remove(self.changed_id)
+            self.changed_id = 0
+
+        self.changed_id = GObject.idle_add(self._emit_changed)
+
+file_monitor = None
+
+def get_file_monitor():
+    global file_monitor
+
+    if file_monitor == None:
+        file_monitor = BinFileMonitor()
+
+    return file_monitor
+
+class DependencyCheckInstallButton(Gtk.Box):
+    def __init__(self, checking_text, install_button_text, binfiles, final_widget=None, satisfied_cb=None):
+        super(DependencyCheckInstallButton, self).__init__(orientation=Gtk.Orientation.HORIZONTAL)
+
+        self.binfiles = binfiles
+        self.satisfied_cb = satisfied_cb
+
+        self.checking_text = checking_text
+        self.install_button_text = install_button_text
+
+        self.stack = Gtk.Stack()
+        self.pack_start(self.stack, False, False, 0)
+
+        self.progress_bar = Gtk.ProgressBar()
+        self.stack.add_named(self.progress_bar, "progress")
+
+        self.progress_bar.set_show_text(True)
+        self.progress_bar.set_text(self.checking_text)
+
+        self.install_warning = Gtk.Label(install_button_text)
+        frame = Gtk.Frame()
+        frame.add(self.install_warning)
+        frame.set_shadow_type(Gtk.ShadowType.OUT)
+        frame.show_all()
+        self.stack.add_named(frame, "install")
+
+        if final_widget:
+            self.stack.add_named(final_widget, "final")
+        else:
+            self.stack.add_named(Gtk.Alignment(), "final")
+
+        self.stack.set_visible_child_name("progress")
+        self.progress_source_id = 0
+
+        self.file_listener = get_file_monitor()
+        self.file_listener_id = self.file_listener.connect("changed", self.on_file_listener_ping)
+
+        self.connect("destroy", self.on_destroy)
+
+        GObject.idle_add(self.check)
+
+    def check(self):
+        self.start_pulse()
+
+        success = True
+
+        for program in self.binfiles:
+            if not GLib.find_program_in_path(program):
+                success = False
+                break
+
+        GObject.idle_add(self.on_check_complete, success)
+
+        return False
+
+    def pulse_progress(self):
+        self.progress_bar.pulse()
+        return True
+
+    def start_pulse(self):
+        self.cancel_pulse()
+        self.progress_source_id = GObject.timeout_add(200, self.pulse_progress)
+
+    def cancel_pulse(self):
+        if (self.progress_source_id > 0):
+            GObject.source_remove(self.progress_source_id)
+            self.progress_source_id = 0
+
+    def on_check_complete(self, result, data=None):
+        self.cancel_pulse()
+        if result:
+            self.stack.set_visible_child_name("final")
+            if self.satisfied_cb:
+                self.satisfied_cb()
+        else:
+            self.stack.set_visible_child_name("install")
+
+    def on_file_listener_ping(self, monitor, data=None):
+        self.stack.set_visible_child_name("progress")
+        self.progress_bar.set_text(self.checking_text)
+        self.check()
+
+    def on_destroy(self, widget):
+        self.file_listener.disconnect(self.file_listener_id)
+        self.file_listener_id = 0
+
+class GSettingsDependencySwitch(SettingsWidget):
+    def __init__(self, label, schema=None, key=None, dep_key=None, binfiles=None, packages=None):
+        super(GSettingsDependencySwitch, self).__init__(dep_key=dep_key)
+
+        self.binfiles = binfiles
+        self.packages = packages
+
+        self.content_widget = Gtk.Alignment()
+        self.label = Gtk.Label(label)
+        self.pack_start(self.label, False, False, 0)
+        self.pack_end(self.content_widget, False, False, 0)
+
+        self.switch = Gtk.Switch()
+        self.switch.set_halign(Gtk.Align.END)
+        self.switch.set_valign(Gtk.Align.CENTER)
+
+        pkg_string = ""
+        for pkg in packages:
+            if pkg_string != "":
+                pkg_string += ", "
+            pkg_string += pkg
+
+        self.dep_button = DependencyCheckInstallButton(_("Checking dependencies"),
+                                                       _("Please install: %s") % (pkg_string),
+                                                       binfiles,
+                                                       self.switch)
+        self.content_widget.add(self.dep_button)
+
+        if schema:
+            self.settings = self.get_settings(schema)
+            self.settings.bind(key, self.switch, "active", Gio.SettingsBindFlags.DEFAULT)
+
